/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { listUnreviewedSubmissions } from "../../modules/genericDataQueries.js";
import { logger } from "../../utils/logger.js";
import type { DatabasePath } from "../../interfaces/databasePath.js";
import type { PrismaClient } from "@prisma/client";
import type { FastifyReply } from "fastify";

/**
 * Queries the database for a specific submission type (based on
 * the route parameter) and returns all unreviewed submissions.).
 * @param database - The Prisma client.
 * @param route - The type of data to list.
 * @param response - The Fastify reply object.
 */
export const listHandler = async(
  database: PrismaClient,
  route: DatabasePath,
  response: FastifyReply,
): Promise<void> => {
  try {
    const data = await listUnreviewedSubmissions(database, route);
    await response.code(200).send({
      data: data.sort((a, b) => {
        return a.createdAt.getTime() - b.createdAt.getTime();
      }),
    });
  } catch (error) {
    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions -- we bein' lazy.
    await logger.error(`/list/${route}`, error as Error);
    await response.status(500).send({ error: error instanceof Error
      ? error.message
      : "Internal Server Error" });
  }
};
